"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [ 
]

#: List of input files
inp_files = [
"t00.abi",
"t01.abi",
"t02.abi",
"t03.abi",
"t04.abi",
"t05.abi",
"t06.abi",
"t07.abi",
"t08.abi",
"t09.abi",
"t11.abi",
"t12.abi",
"t14.abi",
"t16.abi",
"t17.abi",
"t19.abi",
"t20.abi",
"t21.abi",
"t23.abi",
"t24.abi",
"t25.abi",
"t26.abi",
"t27.abi",
"t28.abi",
"t29.abi",
"t30.abi",
]
